@@ -4,8 +4,8 @@
  * Useful functions for command-line parsing.
  *
  * $Author: tom $
- * $Date: 2011/05/16 22:35:03 $
- * $Revision: 1.7 $
+ * $Date: 2013/09/01 22:01:33 $
+ * $Revision: 1.9 $
  */
 
 #define OPTION_ON	((char *)1)
@@ -13,10 +13,10 @@
 
 static void usage (char **argv,
 		   CDK_PARAMS * params,
-		   char *options)
+		   const char *options)
 {
    int n;
-   char *str;
+   const char *str;
 
    fprintf (stderr, "Usage: %s [options]\n\nOptions:\n", baseName (argv[0]));
 
@@ -55,7 +55,7 @@ static int CDKparseSize (char *string, int fullSize)
    }
    else
    {
-      result = (int) strtol (string, (char **)0, 0);
+      result = (int)strtol (string, (char **)0, 0);
    }
    return result;
 }
@@ -64,7 +64,7 @@ static int CDKparseSize (char *string, int fullSize)
  * Parse the string as one of CDK's positioning keywords, or an actual
  * position.
  */
-int CDKparsePosition (char *string)
+int CDKparsePosition (const char *string)
 {
    int result;
 
@@ -94,7 +94,7 @@ int CDKparsePosition (char *string)
    }
    else
    {
-      result = (int) strtol (string, (char **)0, 0);
+      result = (int)strtol (string, (char **)0, 0);
    }
    return result;
 }
@@ -106,10 +106,10 @@ int CDKparsePosition (char *string)
 void CDKparseParams (int argc,
 		     char **argv,
 		     CDK_PARAMS * params,
-		     char *options)
+		     const char *options)
 {
    int code;
-   char *str;
+   const char *str;
 
    memset (params, 0, sizeof (*params));
    params->Box = TRUE;
@@ -184,13 +184,13 @@ char *CDKparamString (CDK_PARAMS * params, int option)
 /*
  * Retrieve the string value of an option, with default for missing value.
  */
-char *CDKparamString2 (CDK_PARAMS * params, int option, char *missing)
+char *CDKparamString2 (CDK_PARAMS * params, int option, const char *missing)
 {
    char *value = ((option > 0 && option < MAX_CDK_PARAMS)
 		  ? params->allParams[option]
 		  : 0);
    if (value == 0)
-      value = missing;
+      value = copyChar (missing);
    return value;
 }
 
@@ -240,7 +240,7 @@ int CDKparamValue (CDK_PARAMS * params, int option, int missing)
    }
    else
    {
-      result = (int) strtol (value, (char **)0, 0);
+      result = (int)strtol (value, (char **)0, 0);
    }
 
    return result;
