@@ -1,9 +1,9 @@
-/* $Id: cdkentry.c,v 1.12 2011/05/16 22:53:13 tom Exp $ */
+/* $Id: cdkentry.c,v 1.14 2012/03/22 09:36:04 tom Exp $ */
 
 #include <cdk_test.h>
 
 #ifdef XCURSES
-char *XCursesProgramName="cdkentry";
+char *XCursesProgramName = "cdkentry";
 #endif
 
 /*
@@ -14,30 +14,30 @@ static int widgetCB (EObjectType cdktype, void *object, void *clientData, chtype
 /*
  * Define file local variables.
  */
-static char *FPUsage = "-f Field Width [-d Display Type] [-F Field Character] [-i Initial Value] [-m Minimum Length] [-M Maximum Length] [-T Title] [-L Label] [-B Buttons] [-O Output file] [-X X Position] [-Y Y Position] [-N] [-S]";
+static const char *FPUsage = "-f Field Width [-d Display Type] [-F Field Character] [-i Initial Value] [-m Minimum Length] [-M Maximum Length] [-T Title] [-L Label] [-B Buttons] [-O Output file] [-X X Position] [-Y Y Position] [-N] [-S]";
 
 /*
  *
  */
 int main (int argc, char **argv)
 {
-   /* Declare variables. */
-   CDKSCREEN *cdkScreen		= 0;
-   CDKENTRY *widget		= 0;
-   CDKBUTTONBOX	*buttonWidget	= 0;
-   WINDOW *cursesWindow		= 0;
-   chtype *holder		= 0;
-   chtype fieldAttr		= A_NORMAL;
-   char *answer			= 0;
-   char *CDK_WIDGET_COLOR	= 0;
-   char *temp			= 0;
-   char filler			= '.';
-   EDisplayType dType		= vMIXED;
-   int buttonCount		= 0;
-   int selection		= 0;
-   int shadowHeight		= 0;
-   FILE *fp			= stderr;
-   char **buttonList		= 0;
+   /* *INDENT-EQLS* */
+   CDKSCREEN *cdkScreen         = 0;
+   CDKENTRY *widget             = 0;
+   CDKBUTTONBOX *buttonWidget   = 0;
+   WINDOW *cursesWindow         = 0;
+   chtype *holder               = 0;
+   chtype fieldAttr             = A_NORMAL;
+   char *answer                 = 0;
+   char *CDK_WIDGET_COLOR       = 0;
+   char *temp                   = 0;
+   char filler                  = '.';
+   EDisplayType dType           = vMIXED;
+   int buttonCount              = 0;
+   int selection                = 0;
+   int shadowHeight             = 0;
+   FILE *fp                     = stderr;
+   char **buttonList            = 0;
    int j1, j2;
 
    CDK_PARAMS params;
@@ -56,25 +56,25 @@ int main (int argc, char **argv)
    int xpos;
    int ypos;
 
-   CDKparseParams(argc, argv, &params, "d:f:i:m:B:F:L:M:O:T:" CDK_MIN_PARAMS);
+   CDKparseParams (argc, argv, &params, "d:f:i:m:B:F:L:M:O:T:" CDK_MIN_PARAMS);
 
-   xpos         = CDKparamValue(&params, 'X', CENTER);
-   ypos         = CDKparamValue(&params, 'Y', CENTER);
-   boxWidget    = CDKparamValue(&params, 'N', TRUE);
-   shadowWidget = CDKparamValue(&params, 'S', FALSE);
+   /* *INDENT-EQLS* */
+   xpos         = CDKparamValue (&params, 'X', CENTER);
+   ypos         = CDKparamValue (&params, 'Y', CENTER);
+   boxWidget    = CDKparamValue (&params, 'N', TRUE);
+   shadowWidget = CDKparamValue (&params, 'S', FALSE);
+   minValue     = CDKparamValue (&params, 'm', 0);
+   fieldWidth   = CDKparamValue (&params, 'f', 0);
+   maxValue     = CDKparamValue (&params, 'M', 256);
+   filename     = CDKparamString (&params, 'f');
+   initValue    = CDKparamString (&params, 'i');
+   buttons      = CDKparamString (&params, 'B');
+   tempFiller   = CDKparamString (&params, 'F');
+   label        = CDKparamString (&params, 'L');
+   outputFile   = CDKparamString (&params, 'O');
+   title        = CDKparamString (&params, 'T');
 
-   minValue     = CDKparamValue(&params, 'm', 0);
-   fieldWidth   = CDKparamValue(&params, 'f', 0);
-   maxValue     = CDKparamValue(&params, 'M', 256);
-   filename     = CDKparamString(&params, 'f');
-   initValue    = CDKparamString(&params, 'i');
-   buttons      = CDKparamString(&params, 'B');
-   tempFiller   = CDKparamString(&params, 'F');
-   label        = CDKparamString(&params, 'L');
-   outputFile   = CDKparamString(&params, 'O');
-   title        = CDKparamString(&params, 'T');
-
-   if ((temp = CDKparamString(&params, 'd')) != 0)
+   if ((temp = CDKparamString (&params, 'd')) != 0)
       dType = char2DisplayType (temp);
 
    /* Make sure all the command line parameters were provided. */
@@ -95,11 +95,11 @@ int main (int argc, char **argv)
    }
 
    /* Set up CDK. */
-   cursesWindow = initscr();
+   cursesWindow = initscr ();
    cdkScreen = initCDKScreen (cursesWindow);
 
    /* Start color. */
-   initCDKColor();
+   initCDKColor ();
 
    /* Check if the user wants to set the background of the main screen. */
    if ((temp = getenv ("CDK_SCREEN_COLOR")) != 0)
@@ -119,29 +119,31 @@ int main (int argc, char **argv)
    /* If the set the filler character, set it now. */
    if (tempFiller != 0)
    {
-      holder	= char2Chtype (tempFiller, &j1, &j2);
-      fieldAttr	= A_ATTRIBUTES & holder[0];
-      filler	= (char)holder[0];
+      holder = char2Chtype (tempFiller, &j1, &j2);
+      fieldAttr = A_ATTRIBUTES & holder[0];
+      filler = (char)holder[0];
       freeChtype (holder);
    }
 
    /* Create the entry widget. */
    widget = newCDKEntry (cdkScreen, xpos, ypos,
-				title, label,
-				fieldAttr,
-				(chtype) filler | fieldAttr,
-				dType, fieldWidth,
-				minValue, maxValue,
-				boxWidget, FALSE);
+			 title, label,
+			 fieldAttr,
+			 (chtype)filler | fieldAttr,
+			 dType, fieldWidth,
+			 minValue, maxValue,
+			 boxWidget, FALSE);
 
    /* Check to make sure we created the dialog box. */
    if (widget == 0)
    {
       /* Shut down curses and CDK. */
       destroyCDKScreen (cdkScreen);
-      endCDK();
+      endCDK ();
 
-      fprintf (stderr, "Error: Could not create the entry field. Is the window too small?\n");
+      fprintf (stderr,
+	       "Error: Could not create the entry field. "
+	       "Is the window too small?\n");
 
       ExitProgram (CLI_ERROR);
    }
@@ -150,24 +152,25 @@ int main (int argc, char **argv)
    if (buttons != 0)
    {
       buttonList = CDKsplitString (buttons, '\n');
-      buttonCount = (int) CDKcountStrings (buttonList);
+      buttonCount = (int)CDKcountStrings ((CDK_CSTRING2) buttonList);
 
       buttonWidget = newCDKButtonbox (cdkScreen,
-					getbegx (widget->win),
-					getbegy (widget->win) + widget->boxHeight - 1,
-					1, widget->boxWidth - 1,
-					0, 1, buttonCount,
-					buttonList, buttonCount,
-					A_REVERSE, boxWidget, FALSE);
+				      getbegx (widget->win),
+				      (getbegy (widget->win)
+				       + widget->boxHeight - 1),
+				      1, widget->boxWidth - 1,
+				      0, 1, buttonCount,
+				      (CDK_CSTRING2) buttonList, buttonCount,
+				      A_REVERSE, boxWidget, FALSE);
       CDKfreeStrings (buttonList);
 
       setCDKButtonboxULChar (buttonWidget, ACS_LTEE);
       setCDKButtonboxURChar (buttonWidget, ACS_RTEE);
 
-     /*
-      * We need to set the lower left and right
-      * characters of the entry field.
-      */
+      /*
+       * We need to set the lower left and right
+       * characters of the entry field.
+       */
       setCDKEntryLLChar (widget, ACS_LTEE);
       setCDKEntryLRChar (widget, ACS_RTEE);
 
@@ -198,28 +201,28 @@ int main (int argc, char **argv)
    {
       /* Determine the height of the shadow window. */
       shadowHeight = (buttonWidget == 0 ?
-			widget->boxHeight :
-			widget->boxHeight + buttonWidget->boxHeight - 1);
+		      widget->boxHeight :
+		      widget->boxHeight + buttonWidget->boxHeight - 1);
 
       /* Create the shadow window. */
       widget->shadowWin = newwin (shadowHeight,
-					widget->boxWidth,
-					getbegy (widget->win) + 1,
-					getbegx (widget->win) + 1);
+				  widget->boxWidth,
+				  getbegy (widget->win) + 1,
+				  getbegx (widget->win) + 1);
 
       /* Make sure we could have created the shadow window. */
       if (widget->shadowWin != 0)
       {
 	 widget->shadow = TRUE;
 
-	/*
-	 * We force the widget and buttonWidget to be drawn so the
-	 * buttonbox widget will be drawn when the widget is activated.
-	 * Otherwise the shadow window will draw over the button widget.
-	 */
-	 drawCDKEntry (widget, ObjOf(widget)->box);
+	 /*
+	  * We force the widget and buttonWidget to be drawn so the
+	  * buttonbox widget will be drawn when the widget is activated.
+	  * Otherwise the shadow window will draw over the button widget.
+	  */
+	 drawCDKEntry (widget, ObjOf (widget)->box);
 	 eraseCDKButtonbox (buttonWidget);
-	 drawCDKButtonbox (buttonWidget, ObjOf(buttonWidget)->box);
+	 drawCDKButtonbox (buttonWidget, ObjOf (buttonWidget)->box);
       }
    }
 
@@ -245,7 +248,7 @@ int main (int argc, char **argv)
    /* End CDK. */
    destroyCDKEntry (widget);
    destroyCDKScreen (cdkScreen);
-   endCDK();
+   endCDK ();
 
    /* Print the value from the widget. */
    if (answer != 0)
@@ -259,9 +262,12 @@ int main (int argc, char **argv)
    ExitProgram (selection);
 }
 
-static int widgetCB (EObjectType cdktype GCC_UNUSED, void *object GCC_UNUSED, void *clientData, chtype key)
+static int widgetCB (EObjectType cdktype GCC_UNUSED,
+		     void *object GCC_UNUSED,
+		     void *clientData,
+		     chtype key)
 {
    CDKBUTTONBOX *buttonbox = (CDKBUTTONBOX *)clientData;
-   injectCDKButtonbox (buttonbox, key);
+   (void) injectCDKButtonbox (buttonbox, key);
    return (TRUE);
 }
